@@ -14,4 +14,15 @@ endpoints = {
     "getImportantCity": hostname + "/teamImportantCity",
     "queryRecord": hostname + "/healthyRecordByUser",
     "password": hostname + "/password",
+    "unHealthyCount": hostname + "/dataV/countUnHealthy",
+    "reportCount": hostname + "/healthyReportCount",
+    "accessCertificateCount": hostname + "/dataV/countAccessCertificate",
+    "isInTeamCityCount": hostname + "/dataV/countIsInTeamCity"
 }
+
+
+identitys = {
+    "student": "1000401",
+    "teacher": "1000402",
+    "other": "1000405"
+}
\ No newline at end of file
